use actix_remote_ip::RemoteIPConfig;
use actix_web::middleware::Logger;
use actix_web::web::Data;
use actix_web::{App, HttpServer};
use light_openid::basic_state_manager::BasicStateManager;
use remote_backend::app_config::AppConfig;

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    env_logger::init_from_env(env_logger::Env::new().default_filter_or("info"));

    let state_manager = Data::new(BasicStateManager::new());

    HttpServer::new(move || {
        App::new()
            .wrap(Logger::default())
            .app_data(state_manager.clone())
            .app_data(Data::new(RemoteIPConfig {
                proxy: AppConfig::get().proxy_ip.clone(),
            }))
    })
    .bind(&AppConfig::get().listen_address)?
    .run()
    .await
}
